{% extends "fobi/generic/add_form_element_entry.html" %}

{% load i18n %}

{% block breadcrumbs-inner %}
      {% if form_entry %}
        {% with form_entry.name as title %}
          <a href="{% url 'fobi.edit_form_entry' form_entry.pk %}">{% if title %} &rsaquo; {{ title }}{% endif %}</a>
        {% endwith %}
        &rsaquo; {% blocktrans with form_element_plugin.name as plugin_name %}Add "{{ plugin_name }}" element to the form{% endblocktrans %}
      {% endif %}
{% endblock breadcrumbs-inner %}