/*
    Document   : bootstrap3_fobi_extras.css
    Created on : Mar 5, 2015, 23:52:17 PM
    Author     : Artur Barseghyan (artur.barseghyan@gmail.com)
    Description:
        `django-fobi` `bootstrap3` theme custom styles.
*/

/*
.theme.theme-bootstrap3 .scrollable-menu {
    height: auto;
    max-height: 200px;
    overflow-x: hidden;
}
*/

.theme.theme-bootstrap3 input[type="checkbox"].form-control,
.theme.theme-bootstrap3 input[type="radio"].form-control{
    height: auto;
    width: auto;
}
