/* font-face */
@font-face {
  font-family: "SocialFoundicons";
  src: url("../fonts/social_foundicons.eot");
  src: url("../fonts/social_foundicons.eot?#iefix") format("embedded-opentype"), url("../fonts/social_foundicons.woff") format("woff"), url("../fonts/social_foundicons.ttf") format("truetype"), url("../fonts/social_foundicons.svg#SocialFoundicons") format("svg");
  font-weight: normal;
  font-style: normal;
}

/* global foundicon styles */
[class*="foundicon-"] {
  display: inline;
  width: auto;
  height: auto;
  line-height: inherit;
  vertical-align: baseline;
  background-image: none;
  background-position: 0 0;
  background-repeat: repeat;
}

[class*="foundicon-"]:before {
  font-family: "SocialFoundicons";
  font-weight: normal;
  font-style: normal;
  text-decoration: inherit;
}

/* icons */
.foundicon-thumb-up:before {
  content: "\f000";
}

.foundicon-thumb-down:before {
  content: "\f001";
}

.foundicon-rss:before {
  content: "\f002";
}

.foundicon-facebook:before {
  content: "\f003";
}

.foundicon-twitter:before {
  content: "\f004";
}

.foundicon-pinterest:before {
  content: "\f005";
}

.foundicon-github:before {
  content: "\f006";
}

.foundicon-path:before {
  content: "\f007";
}

.foundicon-linkedin:before {
  content: "\f008";
}

.foundicon-dribbble:before {
  content: "\f009";
}

.foundicon-stumble-upon:before {
  content: "\f00a";
}

.foundicon-behance:before {
  content: "\f00b";
}

.foundicon-reddit:before {
  content: "\f00c";
}

.foundicon-google-plus:before {
  content: "\f00d";
}

.foundicon-youtube:before {
  content: "\f00e";
}

.foundicon-vimeo:before {
  content: "\f00f";
}

.foundicon-flickr:before {
  content: "\f010";
}

.foundicon-slideshare:before {
  content: "\f011";
}

.foundicon-picassa:before {
  content: "\f012";
}

.foundicon-skype:before {
  content: "\f013";
}

.foundicon-steam:before {
  content: "\f014";
}

.foundicon-instagram:before {
  content: "\f015";
}

.foundicon-foursquare:before {
  content: "\f016";
}

.foundicon-delicious:before {
  content: "\f017";
}

.foundicon-chat:before {
  content: "\f018";
}

.foundicon-torso:before {
  content: "\f019";
}

.foundicon-tumblr:before {
  content: "\f01a";
}

.foundicon-video-chat:before {
  content: "\f01b";
}

.foundicon-digg:before {
  content: "\f01c";
}

.foundicon-wordpress:before {
  content: "\f01d";
}
